import { Fonts } from "@/common/fonts";
import { Metadata, Viewport } from "next";
import { ToastContainer } from "react-toastify";

import "react-toastify/dist/ReactToastify.css";
import "./globals.css";

import Config from "../../config.json";
import Container from "./components/container";
import ThemeProvider from "./components/theme-provider";

export const viewport: Viewport = {
  themeColor: "#3498DB",
};

export const metadata: Metadata = {
  metadataBase: new URL(Config.siteUrl),
  title: {
    template: Config.siteName + " - %s",
    default: Config.siteName,
  },
  description: Config.siteDescription,
  keywords: "Minecraft, APIs, wrapper, utility, development",
  openGraph: {
    title: Config.siteName,
    description: Config.siteDescription,
    url: Config.siteUrl,
    locale: "en_US",
    type: "website",
  },
};

export default function RootLayout({
  children,
}: Readonly<{
  children: React.ReactNode;
}>): JSX.Element {
  return (
    <>
      <html className={Fonts.inter.className} lang="en" suppressHydrationWarning>
        <head />
        <body>
          <ThemeProvider attribute="class" defaultTheme="dark" enableSystem>
            <ToastContainer theme="dark" pauseOnFocusLoss={false} />
            <Container>{children}</Container>
          </ThemeProvider>
        </body>
      </html>
    </>
  );
}
